@@ -39,6 +39,6 @@ data RunMode = HTML| ExpandedTemplates| StandardTemplates | UserTemplateFile Str
 data SourceMode = Included | Excluded
   deriving Show
 
-data FullConfig=FullConfig{resolution::Integer, outputFilename::String, inputUrl::String, runMode::RunMode,paper::String,vector::Bool,copy::Maybe String, font::Bool}
+data FullConfig=FullConfig{resolution::Integer, outputFilename::String, inputUrl::String, runMode::RunMode,paper::String,vector::Bool,copy::Maybe String, font::Bool, mainPath::String}
  deriving Show
 
