@@ -195,7 +195,7 @@ analyse s
                x <- (map
                        (\ i ->
                           if (length l) > i then [intercalate "/" (take i l)] else mzero)
-                       [0, 1])
+                       [0, 1 ,2])
                map (\ i -> u{url_path = i}) x
 
 
@@ -210,7 +210,13 @@ getLemma s
         z = do u <- v
                l <- return $ splitOn "/" $ (unify (url_path u))
                let x = if (length l)>1 then drop 1 l else l
-               return $ intercalate "/" x 
+               let xx = if "index.php" `elem` x 
+                          then  
+                            case dropWhile (/= "index.php") x of
+                              (y:ys)->ys
+                              _ -> [] 
+                          else x
+               return $ intercalate "/" xx 
 
 
 {-DHUN| converts an url given as String into the host (as string) it points to on the wiki.  DHUN-}
