@@ -1,11 +1,13 @@
 import All
 import Control.Monad.State
 import Control.Monad.Error
+import System.Directory
 import System.Environment
 import System.Console.GetOpt
 import System.Exit
 import ImperativeState
 import Data.Maybe
+import System.FilePath.Posix
 data Flag = Verbose |Vector | Version | Templates String | Resolution String | Paper String
               |Copy String | Input String | Output String | LibDir String | MediaWiki | HTML | InternalTemplates | MegaFont
   deriving (Show,Eq)
@@ -120,8 +122,8 @@ boolToInt :: Num a => Bool -> a
 boolToInt True = 1
 boolToInt _ = 0
 
-checkOpts :: [Flag] -> Either MyError FullConfig
-checkOpts o = 
+checkOpts :: FilePath-> [Flag] -> Either MyError FullConfig
+checkOpts cwd o = 
            do resolutionOpt <- atMostOne resolutionPredicate resolutionOption o
               resolutionVal<-case resolutionOpt of 
                            (Just x)-> case reads x of
@@ -150,13 +152,14 @@ checkOpts o =
                                   then Right ExpandedTemplates
                                   else if htmlVal then Right ImperativeState.HTML else Right (StandardTemplates) 
                               else Right ImperativeState.HTML  
-              return FullConfig{resolution=resolutionVal, outputFilename=outputVal,inputUrl=inputVal,runMode=runModeVal,paper=paperVal,vector=vectorVal,copy=copyVal,font=fontVal}
+              return FullConfig{resolution=resolutionVal, outputFilename=outputVal,inputUrl=inputVal,runMode=runModeVal,paper=paperVal,vector=vectorVal,copy=copyVal >>=(return.(  cwd </>)),font=fontVal,mainPath=cwd}
 
 main :: IO ()
 main= do a<-getArgs
          o<-compilerOpts a
          printVersion o
-         case (checkOpts (fst o)) of
+         cwd<-getCurrentDirectory
+         case (checkOpts cwd (fst o)) of
            Right x -> do (xx,_)<-(runStateT (runErrorT (All.all x)) imperativeStateZero)
                          case xx of 
                            Left n->print n
